import csv
import datetime
import io
import os
import zipfile
import sys

from django.db import transaction
from django.utils import timezone
from chrono.agendas.models import Agenda, Event, Booking

if len(sys.argv) < 2:
    sys.exit(0)

if not os.path.exists(sys.argv[1]):
    sys.exit(0)

FILE_PATH = sys.argv[1]
FILE_ENCODING = 'ISO-8859-1'

with zipfile.ZipFile(FILE_PATH) as data:
    csv_fd = io.TextIOWrapper(data.open('extract_prcit_planning_creche.csv'), encoding=FILE_ENCODING)
    reader = csv.reader(csv_fd, delimiter=';')

    # skip header line
    next(reader)
    with transaction.atomic():
        for row in reader:
            agenda_name = u'%s - %s' % (row[10], row[11])
            agenda, created = Agenda.objects.get_or_create(label=agenda_name)
            event_start_dt = '%s %s' % (row[1], row[2])
            # delete all old events
            Event.objects.filter(agenda=agenda, start_datetime__lt=timezone.now()).delete()
            dt = timezone.datetime.strptime(event_start_dt, '%Y%m%d %H%M')
            dt = timezone.make_aware(dt)
            # handle cases when places column is empty
            try:
                places = int(row[8])
                if places < 0:
                    raise ValueError
            except ValueError:
                places = 0
            Event.objects.update_or_create(agenda=agenda, start_datetime=dt, defaults={'places': places})
